@@ -17,7 +17,7 @@ use File::chdir;
 use Path::Class ();
 
 # ABSTRACT: Parallel SSH client
-our $VERSION = '1.06'; # VERSION
+our $VERSION = '1.07'; # VERSION
 
 
 sub main
@@ -99,8 +99,18 @@ sub new
   
   # make sure there is at least one cluster specified
   # and that it doesn't look like a command line option
-  pod2usage({ -exitval => 1, -message => "No clusters specified" })
-    unless @argv;  
+  unless(@argv)
+  {
+    pod2usage({
+      -exitval  => 'NOEXIT',
+      -message  => "No clusters specified", 
+      -sections => [ qw( SYNOPSIS) ],
+      -verbose  => 99,
+    });
+    $self->{list} = 1;
+    $self->ret(1);
+    return $self;
+  }
   pod2usage({ -exitvalue => 1, -message => "Unknown option: $1" })
     if $argv[0] =~ /^--?(.*)$/;
 
@@ -212,23 +222,13 @@ sub server_command
 sub alias
 {
   my($self) = @_;
-  $self->config->alias( default => sub {
-    my %deprecated = $self->config->aliases( default => {} );
-    say STDERR "use of aliases key in configuration is deprecated, use alias instead"
-        if %deprecated;
-    \%deprecated;
-  });
+  $self->config->alias( default => {} );
 }
 
 sub cluster_list
 {
   my($self) = @_;
-  $self->config->cluster( default => sub {
-    my %deprecated = $self->config->clusters( default => {} );
-    say STDERR "use of clusters key in configuration is deprecated, use cluster instead"
-        if %deprecated;
-    \%deprecated;
-  });
+  $self->config->cluster( default => {} );
 }
 
 sub ret
@@ -385,7 +385,6 @@ sub run
   return $self->run_purge  if $self->purge;
   return $self->run_list   if $self->list;
   
-  my $ret = 0;
   my @done;
   my $max = $self->max;
 
@@ -501,6 +500,8 @@ sub run_list
   {
     say "Aliases:  [none]";
   }
+
+  $self->ret;
 }
 
 1;
@@ -517,7 +518,7 @@ App::clad - Parallel SSH client
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =head1 SYNOPSIS
 
